@@ -4,13 +4,13 @@ use strict;
 use warnings;
 use 5.12.0;
 
-our $VERSION = '0.12'; # VERSION
+our $VERSION = '0.13'; # VERSION
 
 sub import {
   my $class = shift;
 
   require "App/SFDC/$_.pm" ## no critic
-    for @_ || qw'Retrieve Deploy'
+    for @_ || qw'Deploy ExecuteAnonymous Retrieve'
 
 }
 
@@ -26,7 +26,7 @@ App::SFDC
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 AUTHOR
 
