@@ -5,13 +5,13 @@ use strict;
 use warnings;
 use 5.10.0;
 
-our $VERSION = '0.12'; # VERSION
+our $VERSION = '0.13'; # VERSION
 
 use Config::Properties;
 use Data::Dumper;
 use File::HomeDir;
 use Log::Log4perl ':easy';
-use WWW::SFDC;
+use WWW::SFDC '0.33';
 
 use Moo::Role;
 use MooX::Options;
@@ -114,7 +114,7 @@ App::SFDC::Role::Credentials - Handle credential command-line input
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 OPTIONS
 
