@@ -6,7 +6,7 @@ use strict;
 use warnings;
 use 5.10.0;
 
-our $VERSION = '0.12'; # VERSION
+our $VERSION = '0.13'; # VERSION
 
 use App::SFDC;
 
@@ -29,11 +29,13 @@ sub usage {"
 # GetOptions, which is why we shift instead of using $_[0]
 
 local $_ = shift || '';
-exit not do {
+exit 1 unless do {
     if (/retrieve/i) {
         App::SFDC::Retrieve->new_with_options->execute();
     } elsif (/deploy/i) {
         App::SFDC::Deploy->new_with_options->execute();
+    } elsif (/executeAnonymous/i) {
+        App::SFDC::ExecuteAnonymous->new_with_options->execute();
     } else {
         print usage;
     }
@@ -49,7 +51,7 @@ SFDC - Command tool for interacting with Salesforce.com
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 DESCRIPTION
 
